@@ -20,6 +20,7 @@
 
 #include "box_db_table.h"
 #include "data_structure/glomconversions.h"
+#include "glom_python.h"
 #include <sstream>
 
 Box_DB_Table::Box_DB_Table()
@@ -88,18 +89,6 @@ bool Box_DB_Table::record_delete(const Gnome::Gda::Value& primary_key_value)
   }
 }
 
-Glib::RefPtr<Gnome::Gda::DataModel> Box_DB_Table::record_new(Gnome::Gda::Value primary_key_value)
-{
-  Field field_primary_key;
-  bool test = get_field_primary_key(field_primary_key);
-  if(test && !GlomConversions::value_is_empty(primary_key_value))
-  {   
-    return Query_execute( "INSERT INTO " + m_strTableName + " (" + get_primarykey_name() + ") VALUES (" + field_primary_key.sql(primary_key_value) + ")" );
-  }
-  else
-    return Glib::RefPtr<Gnome::Gda::DataModel>();
-}
-
 Gnome::Gda::Value Box_DB_Table::get_entered_field_data(const Field& /* field */) const
 {
   //Override this to use Field::set_data() too.
@@ -107,6 +96,11 @@ Gnome::Gda::Value Box_DB_Table::get_entered_field_data(const Field& /* field */)
   return Gnome::Gda::Value(); //null
 }
 
+void Box_DB_Table::set_entered_field_data(const Field& /* field */, const Gnome::Gda::Value& /* value */)
+{
+  //Override this.
+}
+
 bool Box_DB_Table::get_field(const Glib::ustring& name, Field& field) const
 {
   type_vecFields::const_iterator iterFind = std::find_if( m_Fields.begin(), m_Fields.end(), predicate_FieldHasName<Field>(name) );
@@ -223,40 +217,6 @@ unsigned long Box_DB_Table::get_last_auto_increment_value(const Glib::RefPtr<Gno
     return 0;
 }
 
-//static
-Box_DB_Table::type_map_valuetypes Box_DB_Table::get_field_type_names()
-{
-  //TODO: Performance: Cache this map, and/or pass it by reference:
-  type_map_valuetypes mapTypes;
-  
-  mapTypes[Gnome::Gda::VALUE_TYPE_NULL] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_NULL);
-  mapTypes[Gnome::Gda::VALUE_TYPE_BIGINT] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_BIGINT);
-  mapTypes[Gnome::Gda::VALUE_TYPE_BIGUINT] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_BIGUINT);
-  mapTypes[Gnome::Gda::VALUE_TYPE_BINARY] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_BINARY);
-  mapTypes[Gnome::Gda::VALUE_TYPE_BOOLEAN] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_BOOLEAN);
-  mapTypes[Gnome::Gda::VALUE_TYPE_DATE] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_DATE);
-  mapTypes[Gnome::Gda::VALUE_TYPE_DOUBLE] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_DOUBLE);
-  mapTypes[Gnome::Gda::VALUE_TYPE_GEOMETRIC_POINT] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_GEOMETRIC_POINT);
-  mapTypes[Gnome::Gda::VALUE_TYPE_GOBJECT] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_GOBJECT);
-  mapTypes[Gnome::Gda::VALUE_TYPE_INTEGER] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_INTEGER);
-  mapTypes[Gnome::Gda::VALUE_TYPE_LIST] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_LIST);
-  mapTypes[Gnome::Gda::VALUE_TYPE_MONEY] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_MONEY);
-  mapTypes[Gnome::Gda::VALUE_TYPE_NUMERIC] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_NUMERIC);
-  mapTypes[Gnome::Gda::VALUE_TYPE_SINGLE] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_SINGLE);
-  mapTypes[Gnome::Gda::VALUE_TYPE_SMALLINT] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_SMALLINT);
-  mapTypes[Gnome::Gda::VALUE_TYPE_SMALLUINT] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_SMALLUINT);
-  mapTypes[Gnome::Gda::VALUE_TYPE_STRING] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_STRING);
-  mapTypes[Gnome::Gda::VALUE_TYPE_TIME] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_TIME);
-  mapTypes[Gnome::Gda::VALUE_TYPE_TIMESTAMP] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_TIMESTAMP);
-  mapTypes[Gnome::Gda::VALUE_TYPE_TINYINT] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_TINYINT);
-  mapTypes[Gnome::Gda::VALUE_TYPE_TINYUINT] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_TINYUINT);
-  mapTypes[Gnome::Gda::VALUE_TYPE_TYPE] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_TYPE);
-  mapTypes[Gnome::Gda::VALUE_TYPE_UINTEGER] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_UINTEGER);
-  mapTypes[Gnome::Gda::VALUE_TYPE_UNKNOWN] = Gnome::Gda::Value::type_to_string(Gnome::Gda::VALUE_TYPE_UNKNOWN);
-
-  return mapTypes;
-}
-
 bool Box_DB_Table::get_fields_for_table_one_field(const Glib::ustring& table_name, const Glib::ustring& field_name, Field& field) const
 {
   //Initialize output parameter:
