@@ -139,17 +139,40 @@ void Document_Glom::set_relationships(const Glib::ustring& table_name, const typ
 
 Document_Glom::type_vecFields Document_Glom::get_table_fields(const Glib::ustring& table_name) const
 {
-  type_tables::const_iterator iterFind = m_tables.find(table_name);
-  if(iterFind != m_tables.end())
-    return iterFind->second.m_fields;
+  if(!table_name.empty())
+  {
+    type_tables::const_iterator iterFind = m_tables.find(table_name);
+    if(iterFind != m_tables.end())
+    {
+      if(iterFind->second.m_fields.empty())
+      {
+         g_warning("Document_Glom::get_table_fields: table found, but m_fields is empty");
+      }
+      
+      return iterFind->second.m_fields;
+    }
+    else
+    {
+      g_warning("Document_Glom::get_table_fields: table not found in document: %s", table_name.c_str());
+      return type_vecFields();
+    }
+  }
   else
-    return type_vecFields(); 
+  {
+    g_warning("Document_Glom::get_table_fields: table name is empty.");
+    return type_vecFields();
+  }
 }
 
 void Document_Glom::set_table_fields(const Glib::ustring& table_name, const type_vecFields& vecFields)
 {
   if(!table_name.empty())
   {
+    if(vecFields.empty())
+    {
+      g_warning("Document_Glom::set_table_fields(): vecFields is empty: table_name=%s", table_name.c_str());
+    }
+      
     DocumentTableInfo& info = get_table_info_with_add(table_name);
     info.m_fields = vecFields;
 
@@ -462,6 +485,7 @@ Document_Glom::DocumentTableInfo& Document_Glom::get_table_info_with_add(const G
   else
   {
     m_tables[table_name] = DocumentTableInfo();
+    m_tables[table_name].m_info.m_name = table_name;
     return get_table_info_with_add(table_name);
   }
 }
@@ -537,6 +561,13 @@ Glib::ustring Document_Glom::get_default_table() const
     if(iter->second.m_info.m_default)
       return iter->second.m_info.m_name;
   }
+
+  //If there is only one table then pretend that is the default:
+  if(m_tables.size() == 1)
+  {
+    type_tables::const_iterator iter = m_tables.begin();
+    return iter->second.m_info.m_name;
+  }
   
   return Glib::ustring();
 }
@@ -562,7 +593,6 @@ void Document_Glom::set_modified(bool value)
            test = write_to_disk();
            if(test)
            {
-             g_warning("Document_Glom::set_modified(): saved");
              set_modified(false);
            }
          }
@@ -573,6 +603,9 @@ void Document_Glom::set_modified(bool value)
 
 void Document_Glom::load_after_layout_group(const xmlpp::Element* node, LayoutGroup& group)
 {
+  if(!node)
+    return;
+    
   //Get the group details:
   group.set_name( get_node_attribute_value(node, "name") );
   group.m_title = get_node_attribute_value(node, "title");
@@ -585,24 +618,26 @@ void Document_Glom::load_after_layout_group(const xmlpp::Element* node, LayoutGr
   for(xmlpp::Node::NodeList::iterator iter = listNodes.begin(); iter != listNodes.end(); ++iter)
   {
     const xmlpp::Element* element = dynamic_cast<const xmlpp::Element*>(*iter);
-
-    if(element->get_name() == "data_layout_item")
+    if(element)
     {
-      LayoutItem_Field item;
+      if(element->get_name() == "data_layout_item")
+      {
+        LayoutItem_Field item;
 
-      item.set_name( get_node_attribute_value(element, "name") );
+        item.set_name( get_node_attribute_value(element, "name") );
 
-      const guint sequence = get_node_attribute_value_as_decimal(element, "sequence");
-      item.m_sequence = sequence;
-      group.add_item(item, sequence);
-    }
-    else if(element->get_name() == "data_layout_group")
-    {
-      LayoutGroup child_group;
-      //Recurse:
-      load_after_layout_group(element, child_group);
+        const guint sequence = get_node_attribute_value_as_decimal(element, "sequence");
+        item.m_sequence = sequence;
+        group.add_item(item, sequence);
+      }
+      else if(element->get_name() == "data_layout_group")
+      {
+        LayoutGroup child_group;
+        //Recurse:
+        load_after_layout_group(element, child_group);
 
-      group.add_item(child_group);
+        group.add_item(child_group);
+      }
     }
   }                          
 }
@@ -615,7 +650,9 @@ bool Document_Glom::load_after()
   {
     const xmlpp::Element* nodeRoot = get_node_document();
     if(nodeRoot)
-    {    
+    {
+      m_database_title = get_node_attribute_value(nodeRoot, "database_title");
+          
       const xmlpp::Element* nodeConnection = get_node_child_named(nodeRoot, "connection");
       if(nodeConnection)
       {
@@ -687,7 +724,7 @@ bool Document_Glom::load_after()
                 
                 //Field Type:
                 const Glib::ustring field_type = get_node_attribute_value(nodeChild, "type");
-                
+      
                 //Get the type enum for this string representation of the type:
                 Field::glom_field_type field_type_enum = Field::TYPE_INVALID;
                 for(Field::type_map_type_names::const_iterator iter = type_names.begin(); iter !=type_names.end(); ++iter)
@@ -698,15 +735,16 @@ bool Document_Glom::load_after()
                     break;
                   }
                 }
-                
-                field.set_glom_type( field_type_enum );
-
+                        
                 //Default value:
                 const Glib::ustring default_value_text = get_node_attribute_value(nodeChild, "default_value");
                 //Interpret the text as per the field type:
                 bool success = false;
                 field_info.set_default_value( GlomConversions::parse_value(field_type_enum, default_value_text, success, true /* iso_format */) );
                 field.set_field_info(field_info);
+
+                //We set this after set_field_info(), because that gets a glom type from the (not-specified) gdatype. Yes, that's strange, and should probably be more explicit.
+                field.set_glom_type( field_type_enum );
                              
                 doctableinfo.m_fields.push_back(field);
               }
@@ -826,6 +864,8 @@ bool Document_Glom::save_before()
   xmlpp::Element* nodeRoot = get_node_document();
   if(nodeRoot)
   {
+    set_node_attribute_value(nodeRoot, "database_title", m_database_title);
+    
     xmlpp::Element* nodeConnection = get_node_child_named_with_add(nodeRoot, "connection");
     set_node_attribute_value(nodeConnection, "server", m_connection_server); 
     set_node_attribute_value(nodeConnection, "user", m_connection_user); 
@@ -841,6 +881,9 @@ bool Document_Glom::save_before()
     {
       const DocumentTableInfo& doctableinfo = iter->second;
 
+      if(doctableinfo.m_info.m_name.empty())
+        g_warning("Document_Glom::save_before(): table name is empty.");
+        
       if(!doctableinfo.m_info.m_name.empty())
       {
         xmlpp::Element* nodeTable = nodeRoot->add_child("table");
@@ -927,3 +970,26 @@ bool Document_Glom::save_before()
   
   return Bakery::Document_XML::save_before();  
 }
+
+Glib::ustring Document_Glom::get_database_title() const
+{
+  return m_database_title;
+}
+
+void Document_Glom::set_database_title(const Glib::ustring& title)
+{
+  if(m_database_title != title)
+  {
+    m_database_title = title;
+    set_modified();
+  }
+}
+  
+Glib::ustring Document_Glom::get_name() const
+{
+  //Show the database title in the window title bar:
+  if(m_database_title.empty())
+    return Bakery::Document_XML::get_name();
+  else
+    return m_database_title;
+}
