@@ -84,7 +84,7 @@ void Box_Data_Details_Find::fill_related()
 }
 
 
-void Box_Data_Details_Find::on_AddDel_user_changed(guint /* row */, guint /* col */)
+void Box_Data_Details_Find::on_adddel_user_changed(guint /* row */, guint /* col */)
 {
   //Don't do anything.
   //This just blocks the method in the base class.
