@@ -36,7 +36,7 @@ protected:
   virtual void fill_from_database(); //override.
   virtual void fill_related(); //override.
 
-  virtual void on_AddDel_user_changed(guint row, guint col); //override
+  virtual void on_adddel_user_changed(guint row, guint col); //override
 
 
 };
